pub struct Digest(/* private fields */);Expand description
Useful for digest fields (Base58 string). Not a scalar in Sui GraphQL schema. A 32-byte Blake2b256 hash output.
BCS
A Digest’s BCS serialized form is defined by the following:
digest = %x20 32OCTETDue to historical reasons, even though a Digest has a fixed-length of 32, Sui’s binary
representation of a Digest is prefixed with its length meaning its serialized binary form (in
bcs) is 33 bytes long vs a more compact 32 bytes.
Implementations
Sourceimpl Digest
impl Digest
Sourcepub const fn new(digest: [u8; 32]) -> Digest
pub const fn new(digest: [u8; 32]) -> Digest
Generates a new digest from the provided 32 byte array containing u8 values.
Sourcepub const fn inner(&self) -> &[u8; 32]
pub const fn inner(&self) -> &[u8; 32]
Returns a slice to the inner array representation of this digest.
Sourcepub const fn into_inner(self) -> [u8; 32]
pub const fn into_inner(self) -> [u8; 32]
Returns the inner array representation of this digest.
Sourcepub fn from_base58<T>(base58: T) -> Result<Digest, DigestParseError>
pub fn from_base58<T>(base58: T) -> Result<Digest, DigestParseError>
Decodes a digest from a Base58 encoded string.
Sourcepub const fn from_static(base58: &'static str) -> Digest
pub const fn from_static(base58: &'static str) -> Digest
Decodes a digest from a Base58 encoded &’static str.
Similar to from_base58 except any errors are unwrapped, turning them into panics.
Sourcepub fn to_base58(&self) -> String
pub fn to_base58(&self) -> String
Returns a Base58 encoded string representation of this digest.
Sourcepub fn from_bytes<T>(bytes: T) -> Result<Digest, DigestParseError>
pub fn from_bytes<T>(bytes: T) -> Result<Digest, DigestParseError>
Generates a digest from bytes.